<?php

/* AptController.php
 *
 * Copyright (C) 2010 Nicolas Joseph
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Author:
 * 	Nicolas Joseph <nicolas.joseph@valaide.org>
 */

class AptController extends Zend_Controller_Action
{
  private function _fileExtension($filename)
  {
    $path_info = pathinfo($filename);
    return $path_info['extension'];
  }

  private function _parseDate($date)
  {
    $date = str_replace('[', '', $date);
    $date = str_replace('/', '-', $date);
    $pos = strpos($date, ':');
    $date[$pos] = ' ';
    $dt = new DateTime($date);
    return $dt->format('c');
  }

  public function init()
  {
    $this->_helper->layout->setLayout('apt');

    if($this->getRequest()->action == 'debian') {
      $this->view->color = '#FF0000';
      $this->view->bg_color = '#FFEEDD';
      $this->view->a_color = '#FF9797';
      $this->view->logo = 'debian';
    } else {
      $this->view->color = '#FF7700';
      $this->view->bg_color = '#FFDDAA';
      $this->view->a_color = '#FFA554';
      $this->view->logo = 'ubuntu';
    }
  }

  public function indexAction()
  {
    $this->_redirect('/apt/stat');
  }

  public function debianAction()
  {
    $this->view->title = $this->view->translate('debian repository for Val(a)IDE');
    $this->view->headTitle()->headTitle($this->view->title,
                      Zend_View_Helper_Placeholder_Container_Abstract::PREPEND);
  }

  public function ubuntuAction()
  {
    $this->view->title = $this->view->translate('ubuntu repository for Val(a)IDE');
    $this->view->headTitle()->headTitle($this->view->title,
                      Zend_View_Helper_Placeholder_Container_Abstract::PREPEND);
  }

  public function statAction()
  {
    $this->_helper->layout->setLayout('layout');
    $db = Zend_Registry::get('db');

    $config = Zend_Registry::get('config');
    $version = $config->valaide->version;

    $select = $db->select();
    $select->from('access', 'distribution, file, COUNT(file) AS hit')
           ->where('code = 200')
           ->where("file LIKE '%$version%.deb'")
           ->group('distribution')
           ->group('file')
           ->order('COUNT(file) DESC');
    $current_release = $db->fetchAll($select);
    foreach($current_release as &$value) {
      $tmp = explode('/', $value['file']);
      $value['arch'] = $tmp[4];
      if(isset($tmp[6])) {
        $value['file'] = $tmp[6];
      } else {
        $value['file'] = $tmp[5];
      }
    }
    $this->view->current_release = $current_release;

    $select = $db->select();
    $select->from('access', 'file, COUNT(file) AS hit')
           ->where('code = 200')
           ->where("file NOT LIKE '%$version%.deb'")
           ->where("file LIKE '%.deb'")
           ->group('file');
    $results = $db->fetchAll($select);
    $old_release = array();
    foreach($results as $result) {
      preg_match('/_(.*?)-/', $result['file'], $matches);
      if(!isset($old_release[$matches[1]])) {
        $old_release[$matches[1]] = 0;
      }
      $old_release[$matches[1]] += $result['hit'];
    }
    $this->view->old_release = $old_release;
  }

  public function updateAction()
  {
    $this->_helper->layout->disableLayout();
    $this->_helper->viewRenderer->setNoRender(true);

    $db = Zend_Registry::get('db');

    $contents = file_get_contents('/var/log/lighttpd/access.log');
    $contents = explode("\n", $contents);

    $date = $this->getRequest()->getParam('date');
    if(empty($date)) {
      $date = date('d/M/Y');
    }

    $regexp = '#\['. $date .':.*\].*APT-HTTP#';
    $lines = preg_grep($regexp, $contents);
    foreach($lines as $line) {
      $c = explode(' ', $line);
      if($this->_fileExtension($c[6]) == 'deb') {
        $access = array();
        $access['ip'] = $c[0];
        $access['site'] = $c[1];
        list($access['distribution']) = explode('.', $access['site']);
        $access['date'] = $this->_parseDate($c[3]);
        $access['file'] = $c[6];
        $access['code'] = $c[8];
        $db->insert('access', $access);
      }
    }
  }
}

