<?php

/* ContentController.php
 *
 * Copyright (C) 2010 Nicolas Joseph
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Author:
 * 	Nicolas Joseph <nicolas.joseph@valaide.org>
 */

class ContentController extends Zend_Controller_Action
{
  private function _setTitle($title)
  {
    $this->view->title = ucfirst($title);
    $this->view->headTitle()->headTitle($title,
                      Zend_View_Helper_Placeholder_Container_Abstract::PREPEND);
  }

  private function _getAuthors()
  {
    $mailHide = new Zend_Service_ReCaptcha_MailHide();
    $mailHide->setPublicKey(Valide_ReCaptcha::$pubKey);
    $mailHide->setPrivateKey(Valide_ReCaptcha::$privKey);
    return array(
      $this->view->translate('developers') => array(
        array('name' => 'Nicolas Joseph',
              'email' => $mailHide->setEmail('nicolas.joseph@valaide.org'),
              'pledgie' => '10435')
      )
    );
  }

  public function languageAction()
  {
    $params = $this->getRequest()->getParams();
    if(isset($params['lang']))
    {
      Zend_Registry::get('session')->lang = $params['lang'];
    }
    $this->_redirect (Zend_Registry::get('session')->requestUri);
  }

  public function indexAction()
  {
    $this->_setTitle($this->view->translate('index'));
  }

  public function introductionAction()
  {
  }

  public function newsAction()
  {
    $locale = Zend_Registry::get('Zend_Translate')->getLocale();

    $feed = Zend_Feed_Reader::import('http://blog.valaide.org/rss.xml');
    foreach ($feed as $entry) {
      $description = explode('</p>', $entry->getDescription());
      $description = substr($description[0], 3);

      $date = new Zend_Date($entry->getDateModified(), Zend_Date::DATETIME_LONG,
                            $locale);
      $date = $date->get(Zend_Date::DATETIME_SHORT);

      $edata = array(
        'title'        => $entry->getTitle(),
        'description'  => $description,
        'dateModified' => $date,
        'author'       => $entry->getAuthor(),
        'link'         => $entry->getLink(),
        'content'      => $entry->getContent()
      );
      $entries[] = $edata;
    }
    $this->view->feed = $entries;
  }

  public function featuresAction()
  {
    $this->_setTitle($this->view->translate('features'));
  }

  public function screenshotsAction()
  {
		$this->view->dojo()->enable ();
    $this->view->dojo()->requireModule ('dojo.parser')
                       ->requireModule ('dojox.image.Gallery')
                       ->requireModule ('dojo.data.ItemFileReadStore');

    $this->_setTitle($this->view->translate('screenshots'));
  }

  public function imagesJsonAction ()
  {
    $this->_helper->layout->disableLayout ();
    $this->_helper->viewRenderer->setNoRender (true);
    $this->getResponse ()->setHeader ('Content-type', 'text/json');

    $images = array();

    $service = new Zend_Gdata_Photos();

    $query = new Zend_Gdata_Photos_AlbumQuery();
    $query->setUser('gege2061');
    $query->setAlbumName('ValAIDEScreenshots');

    try {
        $albumFeed = $service->getAlbumFeed($query);

        echo '{ items: ['."\n";
        foreach ($albumFeed as $albumEntry) {
          $mediaThumbnailArray = $albumEntry->getMediaGroup()->getThumbnail();
          echo '{
                  "id":"'. $albumEntry->getGphotoId()->getText() .'",
                  "thumb":"'. $mediaThumbnailArray[2]->getUrl() .'",
                  "large":"'. str_replace("/s288/", "/s800/", $mediaThumbnailArray[2]->getUrl()) .'",
                  "title":"'. $albumEntry->getMediaGroup()->getDescription() .'"
                },'."\n";
        }
        echo ']}';
    } catch (Zend_Gdata_App_Exception $e) {
        echo "Error: " . $e->getResponse();
    }
    $this->view->images = $images;
  }

  public function downloadAction()
  {
    $this->_setTitle($this->view->translate('download'));

    $config = Zend_Registry::get('config');
    $this->view->version = $config->valaide->version;
  }

  public function contributeAction()
  {
    $this->_redirect('/wiki/Contribute', array('code' => 301));
  }

  public function codingStandardsAction()
  {
    $this->_redirect('/wiki/CodingStandards', array('code' => 301));
  }

  public function aboutAction()
  {
    $this->_setTitle($this->view->translate('about'));
  }

  public function contactsAction()
  {
    $this->view->authors = $this->_getAuthors();
  }

  public function donateAction()
  {
    $this->_setTitle($this->view->translate('donation'));
    $this->view->authors = $this->_getAuthors();
  }

  public function donationPersonAction()
  {
    $this->_redirect('/content/donation', array('code' => 301));
  }

  public function supportAction()
  {
    $this->_redirect('http://code.google.com/p/valide/issues/list', array('code' => 301));
  }

  public function translationAction()
  {
  }
}

