<?php

/* Timeline.php
 *
 * Copyright (C) 2010 Nicolas Joseph
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Author:
 * 	Nicolas Joseph <nicolas.joseph@valaide.org>
 */

class Valide_Timeline
{
  private $_file;
  private $_level;

  private function add_categorie ($level, $title)
  {
    return '<h'. $level .'>'. $title .'</h'. $level .'>'."\n";
  }

  private function add_task ($status, $title)
  {
    if ($status != '')
    {
      return '<li><span class="'. $status .'">'. $title .'</span></li>'."\n";
    }
    else
    {
      return '<li>'. $title .'</li>'."\n";
    }
  }

  private function open_task ($level)
  {
    $text = '';

    for ($i = 0; $i < $level; $i++)
    {
      if ($this->_level > 0)
      {
        $text .= '<li style="list-style: none;">';
      }
      $text .= '<ul>'."\n";
    }
    return $text;
  }

  private function close_task ($level)
  {
    $text = '';

    for ($i = 0; $i < $level; $i++)
    {
      $text .= '</ul>';
      if ($this->_level - $i > 1)
      {
        $text .= '</li>';
      }
    }
    return $text ."\n";
  }

  private function get_stats ($total, $done, $inprogress, $planned, $todo)
  {
    return '<img alt="timeline" src="/images/timeline.php?total='. $total .'&amp;done='. $done .'&amp;inprogress='. $inprogress .'&amp;planned='. $planned .'&amp;.png" />';
  }

  private function get_contents (&$total, &$done, &$inprogress, &$planned, &$todo)
  {
    $title = '';
    $status = '';
    $content = '';
    $contents = '';
    $lines = array ();
    $current_level = 0;
    $matches = array ();

    $content = file_get_contents ($this->_file);
    $lines = explode ("\n", $content);
    foreach ($lines as $line)
    {
      if (preg_match ('/^[a-z ]*$/i', $line))
      {
        $title = $line;
      }
      elseif (preg_match ('/^[=]*$/', $line))
      {
        $contents .= $this->close_task ($this->_level);
        $this->_level = 0;
        $contents .= $this->add_categorie (2, $title);
        $title = '';
      }
      elseif (preg_match ('/^[-]*$/', $line))
      {
        $contents .= $this->close_task ($this->_level);
        $this->_level = 0;
        $contents .= $this->add_categorie (3, $title);
        $title = '';
      }
      elseif (preg_match ('/^([ ]+)\[([X! *])\] (.*)$/i',
                          $line, $matches))
      {
        $current_level = (strlen ($matches[1])+1) / 2;
        if ($current_level > $this->_level)
        {
          $contents .= $this->open_task ($current_level - $this->_level);
        }
        else if ($current_level < $this->_level)
        {
          $contents .= $this->close_task ($this->_level - $current_level);
        }
        switch ($matches[2])
        {
          case ' ':
            $status = 'todo';
            $todo++;
          break;
          case '!':
            $status = 'planned';
            $planned++;
          break;
          case '*':
            $status = 'inprogress';
            $inprogress++;
          break;
          case 'X':
            $status = 'done';
            $done++;
          break;
        }
        $total++;
        $contents .= $this->add_task ($status, $matches[3]);
        $this->_level = $current_level;
      }
    }
    $contents .= $this->close_task ($this->_level);
    $this->_level = 0;
    return $contents;
  }

  public function __construct($file)
  {
    $this->_file = $file;
  }

  public function __toString()
  {
    /* stat */
    $done = 0;
    $inprogress = 0;
    $planned = 0;
    $todo = 0;
    $total = 0;

    $content = $this->get_contents ($total, $done, $inprogress, $planned, $todo);

    $content = 'Legend: <span class="done">Done</span> ('. $done .')'
              .' - <span class="inprogress">In progress</span> ('. $inprogress .')'
              .' - <span class="planned">Planned</span> ('. $planned .')'
              .' - <span class="todo">Todo</span> ('. $todo .')<br />
      <br />
      '. $this->get_stats ($total, $done, $inprogress, $planned, $todo) .'
      '. $content;

    return $content;
  }
}

